import { createAsyncThunk, createSlice } from '@reduxjs/toolkit'
import { get } from 'lodash'

import { AUTHEN_STORE, DEFAULT_AUTHEN_STATE } from '../constants'
import { login } from '../services'

const authenStore = createSlice({
  name: AUTHEN_STORE,
  initialState: DEFAULT_AUTHEN_STATE,
  reducers: {},
  extraReducers(builder) {
    builder
      .addCase(loginAction.fulfilled, (state, action) => {
        state.userInfo = action.payload.userInfo
        state.access_token = action.payload.access_token
        state.refresh_token = action.payload.refresh_token
      })
      .addCase(loginAction.rejected, (state, action) => {
        console.log('reject', state, action)
      })
  },
})

// redux thunk
export const loginAction = createAsyncThunk(
  `${AUTHEN_STORE}/login`,
  async ({ username, password }: { username: string; password: string }, { rejectWithValue }) => {
    const authenRes = await login(username, password)
    const checkErrCode = get(authenRes, 'data.status.code')
    if (checkErrCode && checkErrCode !== '200') {
      return rejectWithValue(authenRes.data)
    }
    return authenRes.data
  }
)

const authenActions = authenStore.actions
const authenReducer = authenStore.reducer

export { authenActions, authenReducer }
