import { Button, Card, Form, Input, Typography } from 'antd-msb'
import useAccess from 'features/authentication/hooks/useAccess'
import { ERROR_MESSAGE_FORM } from 'features/demo/constants/errorMessage'
import { useFormLogin } from 'features/demo/hooks/useFormLogin'
import { emailValidator } from 'features/demo/utils/validateUtil'
import { useAppSelector } from 'stores'

import './_demoPage1.less'

const DemoPage1 = () => {
  const { userInfo } = useAppSelector((state) => state.authen)
  const access = useAccess()
  const { form, onFinish, onFinishFailed, onclickLogin1, onclickLogin2, isLoading } = useFormLogin()

  return (
    <div className="demo1-wrap">
      <Form
        name="basic"
        form={form}
        initialValues={{ remember: true }}
        onFinish={onFinish}
        onFinishFailed={onFinishFailed}
        autoComplete="off"
      >
        <Form.Item
          label="Username"
          name="username"
          rules={[
            { required: true, message: ERROR_MESSAGE_FORM.USERNAME_REQUIRED },
            { validator: emailValidator },
          ]}
        >
          <Input />
        </Form.Item>

        <Form.Item
          label="Password"
          name="password"
          rules={[{ required: true, message: ERROR_MESSAGE_FORM.PASSWORD_REQUIRED }]}
        >
          <Input.Password />
        </Form.Item>

        <Form.Item wrapperCol={{ span: 16 }}>
          <Button type="primary" onClick={() => onclickLogin1()}>
            Submit 1
          </Button>

          <Button type="primary" onClick={() => onclickLogin2()} loading={isLoading}>
            Submit 2
          </Button>
        </Form.Item>
      </Form>

      <Card className="test-responsive">
        <Typography.Title>CallApi use redux Thunk</Typography.Title>

        <Typography.Paragraph>Username</Typography.Paragraph>
        {userInfo.fullName}
      </Card>

      <Card className="test-responsive" />

      {access.isGuest && <Button type="primary">Button Demo 1 GUEST role</Button>}
    </div>
  )
}

export default DemoPage1
