import { useRef } from 'react'

import { useForm } from 'antd-msb/lib/form/Form'
import { login, login2 } from 'features/authentication/services'
import { loginAction } from 'features/authentication/stores'
import { AuthenState } from 'features/authentication/types'
import { useApi } from 'hooks/useApi'
import { useAppDispatch } from 'stores'

export const useFormLogin = () => {
  const dispatch = useAppDispatch()
  const [form] = useForm()

  // demo normal case
  // eslint-disable-next-line @typescript-eslint/no-unused-vars
  const authen2 = useApi<AuthenState>(login2)

  // demo sử dụng useApi với param từ form submit
  const loginState = useRef({ username: '', password: '' })
  const authen = useApi<AuthenState>(
    () => login(loginState.current.username, loginState.current.password),
    {
      immediate: false,
    }
  )

  const onFinish = (values: any) => {
    console.log('Success:', values)
  }

  const onFinishFailed = (errorInfo: any) => {
    console.log('Failed:', errorInfo)
  }

  // submit form, sử dụng redux thunk function
  const onclickLogin1 = async () => {
    form
      .validateFields()
      .then(async (values) => {
        const result = await dispatch(loginAction(values)).unwrap()
        console.log('onclickLogin1', result)
      })
      .catch((err) => {
        console.log(err)
      })
  }

  // submit form, sử dụng execute từ useApi hook
  const onclickLogin2 = async () => {
    form
      .validateFields()
      .then(async (values) => {
        loginState.current = values
        const result = await authen.execute()
        console.log('onclickLogin2', result)
      })
      .catch((err) => {
        console.log(err)
      })
  }

  return {
    form,
    onFinish,
    onFinishFailed,
    onclickLogin1,
    onclickLogin2,
    isLoading: authen.isLoading,
  }
}
