import { ERROR_MESSAGES } from 'constants/errorMessages'

import { notification } from 'antd-msb'
import { AxiosInstance, AxiosError } from 'axios'
import { get } from 'lodash'

const setMainInterceptor = (instance: AxiosInstance) => {
  instance.interceptors.request.use(async (config) => {
    const customConfigs = { ...config }

    // write code to handle request here
    return customConfigs
  })

  instance.interceptors.response.use(
    (response) =>
      // write code to handle response here
      response,
    (error: AxiosError) => {
      // write code to handle error response
      console.log('[AXIOS - ERROR]', error)

      const axiosErrorCode = get(error, 'code')
      const httpErrorCode = get(error, 'response.status')
      if (axiosErrorCode === 'ERR_SYS') {
        notification.error({
          message: ERROR_MESSAGES.ERR_SYS,
        })
        return
      }

      switch (httpErrorCode) {
        case 403:
          // store.dispatch(authActions.logoutUser())
          notification.warn({
            message: ERROR_MESSAGES.API_403,
          })
          return
        default:
          return Promise.reject(error)
      }
    }
  )
}

export { setMainInterceptor }
