import { combineReducers, configureStore } from '@reduxjs/toolkit'
import { AUTHEN_STORE } from 'features/authentication/constants'
import { authenReducer } from 'features/authentication/stores'
import { AuthenState } from 'features/authentication/types'
import { TypedUseSelectorHook, useDispatch, useSelector } from 'react-redux'
import {
  persistStore,
  persistReducer,
  FLUSH,
  REHYDRATE,
  PAUSE,
  PERSIST,
  PURGE,
  REGISTER,
} from 'redux-persist'
import storage from 'redux-persist/lib/storage'
import { LoadingState } from 'types/loading'

import { loadingReducer, LOADING_STORE } from './loading'

export type RootState = {
  [AUTHEN_STORE]: AuthenState
  [LOADING_STORE]: LoadingState
}

const persistConfig = {
  key: 'root',
  storage,
  whitelist: [AUTHEN_STORE],
}

const rootReducer = combineReducers({
  [LOADING_STORE]: loadingReducer,
  [AUTHEN_STORE]: authenReducer,
})

const persistedReducer = persistReducer(persistConfig, rootReducer)

const store = configureStore({
  reducer: persistedReducer,
  middleware: (getDefaultMiddleware) =>
    getDefaultMiddleware({
      serializableCheck: {
        ignoredActions: [FLUSH, REHYDRATE, PAUSE, PERSIST, PURGE, REGISTER],
      },
    }),
})

type AppDispatch = typeof store.dispatch
const useAppDispatch: () => AppDispatch = useDispatch
const useAppSelector: TypedUseSelectorHook<RootState> = useSelector

const persistor = persistStore(store)

export { store, persistor, useAppDispatch, useAppSelector }
